#!/bin/sh
#
# The software is provided 'as is' and the author 
# disclaims all warranties with regard to this software 
# including all implied warranties of merchantability and 
# fitness. In no event shall the author be liable for any 
# special, direct, indirect, or consequential damages or 
# any damages whatsoever resulting from loss of use, data 
# or profits, whether in an action of contract, negligence 
# or other tortious action, arising out of or in connection 
# with the use or performance of this software.
#
#
#  SRC Tools
#  src.sh
#
#  Created by Mark C. Erickson on 09/04/21.
#  Copyright © 2021-2022 Auricula. All rights reserved.
#
# 1.0.1 -> added support for homebrew on the M1
# 1.0.1 -> fixed an afinfo bug, changed $basename to "$path"
# 1.0.2 -> expanded switches, more src choices, link to web site

version=1.0.1

echo ''
echo 'SRC Tool for "bash": v'$version
echo 'Locating dependencies...'

# Sanity Checks ...
# sanity check, sox
#
if [ -e /usr/local/bin/sox ] || [ -e /opt/homebrew/bin/sox ]
then 
	echo '... found sox'
else
	echo 'sox not found, please install sox in /usr/local/bin'
	exit -1
fi

# sanity check, libsamplerate
#
if [ -e /usr/local/bin/sndfile-resample ] || [ -e /opt/homebrew/bin/sndfile-resample ] 
then 
	echo '... found libsamplerate'
else
	echo 'libsamplerate not found, please install sndfile-resample in /usr/local/bin'
	exit -2
fi

# sanity check, afinfo
#
if [ -e /usr/bin/afinfo ] 
then 
	echo '... found afinfo'
else
	echo 'afinfo not found, please install afinfo in /usr/local/bin'
	exit -3
fi

echo 'Success! All dependencies found'
# end sanity checks

echo ''
echo 'Use this script to sample rate convert an audio file'
echo ''
echo 'Please enter the path to an *.wav audio file.'
echo 'Please do not put spaces in the file name, such as: "My Bad.wav", instead: "My_Good.wav"'
echo '   waiting on you now ...'
echo ''
read path
dirname=${path%/*}
basename=${path##*/}
noext=${basename%%.*}
ext="${basename##*.}"
#echo 'Full path:' $path
#echo 'Directory: ' $dirname
echo ''
echo '... attempting to use: '$basename
#echo 'Filename w/o ext: ' $noext

# sanity check, wav
#
if [ "$ext" != "wav" ]
then
	echo 'Error: file not WAV format'
	echo 'Exiting...'
	exit -4
fi

# sanity check, directory writable ?
#
w=0
check_dir() {
    [ -r "$1" ] && [ -w "$1" ] && w=1 || w=0
}
check_dir "$dirname"
if [ $w == 1 ]
then
    echo '... the directory is writable'
else
    echo 'Error: the directory is not writable'
    echo 'Exiting...'
    exit -5
fi

echo ''
echo 'Optional: Enter the target sample rate...'
echo 'Please do not put decimal points, commas or "kHz" your entry'
echo '   waiting on you now ... to use 44100, hit return'
echo ''
read path2

if [ "$path2" == "" ]
then
	path2=44100		# default sample rate
    tput cuu1       # move cursor up by one line
    tput el         # clear the line
    echo $path2
fi

echo ''
    
val=$(afinfo "$path" | grep format | sed 's/.*ch,\(.*\)/\1/g')
val2=$(echo $val | sed 's/\Hz.*//g')
val3=$(echo $val2 | sed 's/[^0-9.]*//g')
if [ "$path2" == "$val3" ]
then
    echo '... File already has a sample rate of '$val3
    echo 'Exiting...'
    echo ''
    exit -6
fi

#begin 1.0.2
open https://www.auriculaonline.com/pwyw/src/
#echo ''
echo 'Optional: Enter a number [1..3] for the conversion schema ...'
echo 'Lower numbers will result in fewer conversions'
echo '   waiting on you now ... to use 1, hit return'
echo ''
read path3

if [ "$path3" == "" ]
then
	path3=1		    # default conversion schema
	tput cuu1       # move cursor up by one line
    tput el         # clear the line
    echo $path3
fi

echo ''
#end 1.0.2

cd "$dirname"

# sox conversions
#
#sox $basename '44k-v'$basename rate -v 44100
#sox $basename '44k-va'$basename rate -v -a 44100
#sox $basename '44k-vp'$basename rate -v -p 33 44100
#sox $basename '44k-vp25a'$basename rate -v -p 25 -a 44100
#sox $basename '44k-vp30a'$basename rate -v -p 30 -a 44100
#sox $basename '44k-vp35a'$basename rate -v -p 35 -a 44100
#sox $basename '44k-vp40a'$basename rate -v -p 40 -a 44100
#sox $basename '44k-vp45a'$basename rate -v -p 45 -a 44100
#sox $basename '44k-vp50a'$basename rate -v -p 50 -a 44100

sox $basename 'sox_vp40ab85-'$basename rate -v -p 40 -a -b 85 $path2
sox $basename 'sox_v-'$basename rate -v $path2
sox $basename 'sox_h-'$basename rate -h $path2
sox $basename 'sox_l-'$basename rate -l $path2

if [ $path3 -gt 1 ] 
then 
	sox $basename 'sox_vI-'$basename rate -v -I $path2
	sox $basename 'sox_vM-'$basename rate -v -M $path2
	sox $basename 'sox_vMa-'$basename rate -v -M -a $path2
fi

if [ $path3 -gt 2 ] 
then 
	sox $basename 'sox_mb90-'$basename rate -m -b 90 $path2
	sox $basename 'sox_va-'$basename rate -v -a $path2
	sox $basename 'sox_m-'$basename rate -m $path2
fi

#sox $basename '44k-vp40ab90'$basename rate -v -p 40 -a -b 90 44100
#sox $basename '44k-vp40ab95'$basename rate -v -p 40 -a -b 95 44100

# end sox

# libsamplerate conversions
#
sndfile-resample -to $path2 -c 0 $basename 'src_c0-'$basename
sndfile-resample -to $path2 -c 2 $basename 'src_c2-'$basename

if [ $path3 -gt 1 ] 
then 
	sndfile-resample -to $path2 -c 1 $basename 'src_c1-'$basename 
	sndfile-resample -to $path2 -c 3 $basename 'src_c3-'$basename 
fi

if [ $path3 -gt 2 ] 
then 
	sndfile-resample -to $path2 -c 4 $basename 'src_c4-'$basename 
fi
# end libsamplerate

exit 0
